"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var appender_1 = require("../decorators/appender");
var BaseAppender_1 = require("../class/BaseAppender");
/**
 * ## Console Appender
 *
 * This appender uses node’s console object to write log events. It can also be used in the browser, if you’re using browserify or something similar. Be aware that writing a high volume of output to the console can make your application use a lot of memory. If you experience this problem, try switching to the stdout appender.
 *
 * ## Configuration
 *
 * * type - console
 * * layout - object (optional, defaults to colouredLayout) - see layouts
 *
 * Note that all log events are output using console.log regardless of the event’s level (so ERROR events will not be logged using console.error)
 *
 * ## Example
 *
 * ```typescript
 * import {Logger} from "ts-log-debug";
 *
 * const logger = new Logger("loggerName");
 *
 * logger.appenders.set("console", {
 *     type: "console",
 *     levels: ["debug", "info", "trace"]
 * });
 * ```
 *
 * @private
 */
var ConsoleAppender = /** @class */ (function (_super) {
    tslib_1.__extends(ConsoleAppender, _super);
    function ConsoleAppender() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.log = console.log.bind(console);
        return _this;
    }
    ConsoleAppender.prototype.write = function (loggingEvent) {
        this.log(this.layout(loggingEvent, this.config.timezoneOffset));
    };
    ConsoleAppender = tslib_1.__decorate([
        appender_1.Appender({ name: "console" })
    ], ConsoleAppender);
    return ConsoleAppender;
}(BaseAppender_1.BaseAppender));
exports.ConsoleAppender = ConsoleAppender;
//# sourceMappingURL=ConsoleAppender.js.map