'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
// The module 'vscode' contains the VS Code extensibility API. Import the module and reference it with the alias vscode in your code below.
const vscode = require("vscode");
const path = require("path");
const fs = require("fs");
// Imports from our sources
const KiuwanService_1 = require("./KiuwanService");
const KiuwanSourceProvider_1 = require("./KiuwanSourceProvider");
const KiuwanDetailsProvider_1 = require("./KiuwanDetailsProvider");
const KiuwanDefectsProvider_1 = require("./KiuwanDefectsProvider");
const KiuwanDefectsProvider_2 = require("./KiuwanDefectsProvider");
const KiuwanDefectsProvider_3 = require("./KiuwanDefectsProvider");
const KiuwanDefectsProvider_4 = require("./KiuwanDefectsProvider");
const ConfigLog4j_1 = require("./utils/ConfigLog4j");
const Utils = require("./utils/utils");
const kiuwanDetailsProvider = new KiuwanDetailsProvider_1.KiuwanDetailsProvider();
const kiuwanDefectsProvider = new KiuwanDefectsProvider_1.KiuwanDefectsProvider();
const kiuwanSourceProvider = new KiuwanSourceProvider_1.KiuwanSourceProvider(kiuwanDefectsProvider);
const log = ConfigLog4j_1.LogFactory.getLogger("k4d.extension");
// This method is called when your extension is activated. Your extension is activated the very first time the command is executed.
function activate(context) {
    log.info('Kiuwan For Developers (K4D) extension activated. Welcome!');
    // Register providers for all three sections of kiuwan-defects activity bar
    vscode.window.registerTreeDataProvider('kiuwan-defects-source', kiuwanSourceProvider);
    vscode.window.registerTreeDataProvider('kiuwan-defects-list', kiuwanDefectsProvider);
    vscode.window.registerTreeDataProvider('kiuwan-defects-details', kiuwanDetailsProvider);
    // The command has been defined in the package.json file (parameter 'commandId' must match the command field in package.json)
    let disposable = vscode.commands.registerCommand('k4d.enterPassword', enterPassword);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.checkConnection', checkConnection);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.getApplications', configureApplication);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.getActionPlans', configureActionPlan);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.getAuditDeliveries', configureAuditDelivery);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.getDeliveries', configureDelivery);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.kiuwan-defects.refresh', refreshDefects);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.browseToFile', browseToFile);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.refreshDetails', refreshDetails);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.browseToDocumentation', KiuwanDefectsProvider_2.browseToDocumentation);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.muteDefect', KiuwanDefectsProvider_3.muteDefect);
    context.subscriptions.push(disposable);
    disposable = vscode.commands.registerCommand('k4d.changeDefectStatus', KiuwanDefectsProvider_4.changeDefectStatus);
    context.subscriptions.push(disposable);
}
exports.activate = activate;
// This method is called when your extension is deactivated.
function deactivate() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield KiuwanService_1.KiuwanService.getKiuwanLicenseApi().ungetLicense();
            log.info('Floating license release operation successfully completed');
        }
        catch (error) {
            log.warn('Floating license release operation completed with errors: ' + error);
        }
        finally {
            log.info('Kiuwan For Developers (K4D) extension deactivated. See you!');
        }
    });
}
exports.deactivate = deactivate;
function enterPassword() {
    vscode.window.showInputBox({
        placeHolder: 'Please type your Kiuwan account password.',
        prompt: 'This password will be stored encrypted as a User Setting in `Extensions > Kiuwan`',
        password: true
    }).then(selection => {
        if (!selection)
            return;
        let section = 'kiuwan.connectionSettings.credentials.password';
        try {
            let encrypted = Utils.encrypt(selection);
            vscode.workspace.getConfiguration().update(section, encrypted, vscode.ConfigurationTarget.Global).then(function onfulfilled() { vscode.window.showInformationMessage('Password successfully updated'); }, function onrejected() { vscode.window.showInformationMessage('Password update failed, it is still set to old value', 'OK'); });
            // uncomment for debugging purposes
            //let decrypted: string = Utils.decrypt(encrypted);
            //vscode.window.showInformationMessage(`Encrypted password then decrypted to: "${decrypted}"`);
        }
        catch (error) {
            vscode.window.showErrorMessage('Password update failed, error: ' + error, 'OK');
            log.error(error.stack);
        }
    });
}
function checkConnection() {
    let kiuwanBasePath = KiuwanService_1.getBasePath();
    KiuwanService_1.KiuwanService.getInformationApi().getInformation().then(result => {
        if (result && result.response && result.response.statusCode === 200) {
            let message = `Connection to ${kiuwanBasePath} succeeded for user ${result.body.username}`;
            vscode.window.showInformationMessage(message);
            log.info('Check connection OK, result is: ' + message);
        }
        else {
            let message = `Connection to ${kiuwanBasePath} failed with HTTP status ${result.response.statusCode} and message ${result.response.statusMessage}`;
            vscode.window.showErrorMessage(message, 'OK');
            log.info('Check connection KO, result is: ' + message);
        }
    }).catch(error => {
        if (error.message) {
            let message = `Connection to ${kiuwanBasePath} failed, cause: ${error.message}`;
            vscode.window.showErrorMessage(message, 'OK');
            log.error(message);
            if (error.stack)
                log.error(error.stack);
        }
        else if (error.response) {
            let message = `Connection to ${kiuwanBasePath} failed with HTTP status ${error.response.statusCode} and message ${error.response.statusMessage}`;
            vscode.window.showErrorMessage(message, 'OK');
            log.error('Check connection error, result is: ' + message);
        }
    });
}
function configureApplication() {
    return __awaiter(this, void 0, void 0, function* () {
        if (vscode.workspace.name == null) {
            vscode.window.showInformationMessage('Please open a workspace before linking it to a Kiuwan application', 'OK');
            return;
        }
        KiuwanService_1.KiuwanService.getApplicationApi().getApplications().then(result => {
            if (result.body) {
                // Extract proper data structures from result's body
                let applications = [];
                result.body.forEach((app) => {
                    applications.push({
                        label: app.name,
                        description: app.description,
                        value: app
                    });
                });
                // Show applications combobox in top bar
                vscode.window.showQuickPick(applications, {
                    placeHolder: 'Please select the Kiuwan application to associate to this project.'
                }).then(selection => {
                    if (!selection)
                        return;
                    // Update user settings
                    let section = 'kiuwan.connectionSettings.remoteApplication.name';
                    let value = selection.value.name;
                    vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                        let remoteApplication = vscode.workspace.getConfiguration('kiuwan.connectionSettings.remoteApplication').get('name');
                        vscode.window.showInformationMessage('Application successfully updated to ' + remoteApplication, 'OK');
                    }, function onrejected() {
                        let remoteApplication = vscode.workspace.getConfiguration('kiuwan.connectionSettings.remoteApplication').get('name');
                        vscode.window.showInformationMessage('Application update failed, it is still set to ' + remoteApplication, 'OK');
                    });
                });
            }
            else if (result.response) {
                let msg = 'There\'s no body in get applications result (HTTP status = ' + result.response.statusCode + ' - ' + result.response.statusMessage + ')';
                vscode.window.showErrorMessage(msg, 'OK');
            }
        }).catch(error => {
            vscode.window.showErrorMessage(error.message, 'OK');
        });
    });
}
function configureActionPlan() {
    return __awaiter(this, void 0, void 0, function* () {
        let application = vscode.workspace.getConfiguration('kiuwan.connectionSettings.remoteApplication').get('name');
        if (application) {
            KiuwanService_1.KiuwanService.getActionPlanApi().getActionPlans(application).then(result => {
                if (result.body) {
                    if (result.body.length < 1) {
                        vscode.window.showErrorMessage('Kiuwan application ' + application + ' has no action plans.', 'OK');
                        return;
                    }
                    // Extract proper data structures from result's body
                    let actionplans = [];
                    result.body.forEach((plan) => {
                        actionplans.push({
                            label: plan.name,
                            description: plan.description,
                            value: plan
                        });
                    });
                    // Show action plans combobox in top bar
                    vscode.window.showQuickPick(actionplans, {
                        placeHolder: 'Please select the Action Plan to associate as source analysis.'
                    }).then(selection => {
                        if (!selection)
                            return;
                        // Update user settings
                        let section = 'kiuwan.defectsList.analysisSource';
                        let value = 'Action plan';
                        vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis successfully updated to ' + analysisSource, 'OK');
                            section = 'kiuwan.defectsList.analysisSourceActionPlan.name';
                            value = selection.value.name;
                            vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                                let actionPlan = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceActionPlan').get('name');
                                vscode.window.showInformationMessage('Action Plan successfully updated to ' + actionPlan, 'OK');
                            }, function onrejected() {
                                let actionPlan = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceActionPlan').get('name');
                                vscode.window.showInformationMessage('Action Plan update failed, it is still set to ' + actionPlan, 'OK');
                            });
                        }, function onrejected() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis update failed, it is still set to ' + analysisSource, 'OK');
                        });
                    });
                }
                else if (result.response) {
                    let msg = 'There\'s no body in get action plans result (HTTP status = ' + result.response.statusCode + ' - ' + result.response.statusMessage + ')';
                    vscode.window.showErrorMessage(msg, 'OK');
                }
            }).catch(error => {
                vscode.window.showErrorMessage(error.message, 'OK');
            });
        }
        else {
            let msg = 'This command lists the action plans of a Kiuwan application, you have to choose a Kiuwan application first.';
            vscode.window.showErrorMessage(msg, 'OK');
        }
    });
}
function configureAuditDelivery() {
    return __awaiter(this, void 0, void 0, function* () {
        let application = vscode.workspace.getConfiguration('kiuwan.connectionSettings.remoteApplication').get('name');
        if (application) {
            let maxdays = undefined; // based on configuration combobox (e.g. today = 1, last week = 7)
            let page = 1; // always one, one and the first page
            let count = undefined; // based on configuration combobox (e.g. last 10 = 10)
            let auditSuccess = false; // false for audit deliveries (failed ones); undefined for deliveries (both failed and passed)
            let filterPurgedAnalyses = true; // always filter purged analyses, someone removed them for a good reason
            let changeRequestFilter = undefined; // no changeRequestFilter, k4d for vscode doesnt support filtering by CR message
            let auditRange = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceAuditDelivery').get('pickRange');
            switch (auditRange) {
                case 'Last 30 days':
                    maxdays = 30;
                    break;
                case 'Last 7 days':
                    maxdays = 7;
                    break;
                case 'Today':
                    maxdays = 1;
                    break;
                case 'Last 10':
                default:
                    count = 10;
                    break;
            }
            KiuwanService_1.KiuwanService.getDeliveryApi().listDeliveries(application, maxdays, page, count, auditSuccess, filterPurgedAnalyses, changeRequestFilter).then(result => {
                if (result.body) {
                    if (result.body.length < 1) {
                        vscode.window.showErrorMessage('Kiuwan application ' + application + ' has no audit deliveries.', 'OK');
                        return;
                    }
                    // Extract proper data structures from result's body
                    let audits = [];
                    result.body.forEach((audit) => {
                        audits.push({
                            label: audit.code,
                            description: audit.changeRequest + ' • ' + audit.label + ' • ' + new Date(audit.creationDate).toLocaleString(),
                            value: audit
                        });
                    });
                    // Show audit deliveries combobox in top bar
                    vscode.window.showQuickPick(audits, {
                        placeHolder: 'Please select the Audit Delivery to associate as source analysis.'
                    }).then(selection => {
                        if (!selection)
                            return;
                        // Update user settings
                        let section = 'kiuwan.defectsList.analysisSource';
                        let value = 'Audit delivery';
                        vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis successfully updated to ' + analysisSource, 'OK');
                            section = 'kiuwan.defectsList.analysisSourceAuditDelivery.code';
                            value = selection.value.code;
                            vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                                let audit = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceAuditDelivery').get('code');
                                vscode.window.showInformationMessage('Audit Delivery successfully updated to ' + audit, 'OK');
                            }, function onrejected() {
                                let audit = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceAuditDelivery').get('code');
                                vscode.window.showInformationMessage('Audit Delivery update failed, it is still set to ' + audit, 'OK');
                            });
                        }, function onrejected() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis update failed, it is still set to ' + analysisSource, 'OK');
                        });
                    });
                }
                else if (result.response) {
                    let msg = 'There\'s no body in get audit deliveries result (HTTP status = ' + result.response.statusCode + ' - ' + result.response.statusMessage + ')';
                    vscode.window.showErrorMessage(msg, 'OK');
                }
            }).catch(error => {
                vscode.window.showErrorMessage(error.message, 'OK');
            });
        }
        else {
            let msg = 'This command lists the audit deliveries of a Kiuwan application, you have to choose a Kiuwan application first.';
            vscode.window.showErrorMessage(msg, 'OK');
        }
    });
}
function configureDelivery() {
    return __awaiter(this, void 0, void 0, function* () {
        let application = vscode.workspace.getConfiguration('kiuwan.connectionSettings.remoteApplication').get('name');
        if (application) {
            let maxdays = undefined; // based on configuration combobox (e.g. today = 1, last week = 7)
            let page = 1; // always one, one and the first page
            let count = undefined; // based on configuration combobox (e.g. last 10 = 10)
            let auditSuccess = undefined; // false for audit deliveries (failed ones); undefined for deliveries (both failed and passed)
            let filterPurgedAnalyses = true; // always filter purged analyses, someone removed them for a good reason
            let changeRequestFilter = undefined; // no changeRequestFilter, k4d for vscode doesnt support filtering by CR message
            let deliveryRange = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceDelivery').get('pickRange');
            switch (deliveryRange) {
                case 'Last 30 days':
                    maxdays = 30;
                    break;
                case 'Last 7 days':
                    maxdays = 7;
                    break;
                case 'Today':
                    maxdays = 1;
                    break;
                case 'Last 10':
                default:
                    count = 10;
                    break;
            }
            KiuwanService_1.KiuwanService.getDeliveryApi().listDeliveries(application, maxdays, page, count, auditSuccess, filterPurgedAnalyses, changeRequestFilter).then(result => {
                if (result.body) {
                    if (result.body.length < 1) {
                        vscode.window.showErrorMessage('Kiuwan application ' + application + ' has no deliveries.', 'OK');
                        return;
                    }
                    // Extract proper data structures from result's body
                    let deliveries = [];
                    result.body.forEach((delivery) => {
                        deliveries.push({
                            label: delivery.code,
                            description: delivery.changeRequest + ' • ' + delivery.label + ' • ' + new Date(delivery.creationDate).toLocaleString(),
                            value: delivery
                        });
                    });
                    // Show deliveries combobox in top bar
                    vscode.window.showQuickPick(deliveries, {
                        placeHolder: 'Please select the Delivery to associate as source analysis.'
                    }).then(selection => {
                        if (!selection)
                            return;
                        // Update user settings
                        let section = 'kiuwan.defectsList.analysisSource';
                        let value = 'Delivery';
                        vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis successfully updated to ' + analysisSource, 'OK');
                            section = 'kiuwan.defectsList.analysisSourceDelivery.code';
                            value = selection.value.code;
                            vscode.workspace.getConfiguration().update(section, value, vscode.ConfigurationTarget.Workspace).then(function onfulfilled() {
                                let delivery = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceDelivery').get('code');
                                vscode.window.showInformationMessage('Delivery successfully updated to ' + delivery, 'OK');
                            }, function onrejected() {
                                let delivery = vscode.workspace.getConfiguration('kiuwan.defectsList.analysisSourceDelivery').get('code');
                                vscode.window.showInformationMessage('Delivery update failed, it is still set to ' + delivery, 'OK');
                            });
                        }, function onrejected() {
                            let analysisSource = vscode.workspace.getConfiguration('kiuwan.defectsList').get('analysisSource', '');
                            vscode.window.showInformationMessage('Source analysis update failed, it is still set to ' + analysisSource, 'OK');
                        });
                    });
                }
                else if (result.response) {
                    let msg = 'There\'s no body in get deliveries result (HTTP status = ' + result.response.statusCode + ' - ' + result.response.statusMessage + ')';
                    vscode.window.showErrorMessage(msg, 'OK');
                }
            }).catch(error => {
                vscode.window.showErrorMessage(error.message, 'OK');
            });
        }
        else {
            let msg = 'This command lists the deliveries of a Kiuwan application, you have to choose a Kiuwan application first.';
            vscode.window.showErrorMessage(msg, 'OK');
        }
    });
}
function refreshDefects() {
    // Force client configuration, in case user just changed connection settings
    log.info("Refreshing Kiuwan defects sections...");
    // Make 'Source Provider' refresh its contents (it will call kiuwanDefectsProvider's refresh if license check is ok)
    kiuwanSourceProvider.refresh();
    // Call 'Details Provider' without contents to ensure nothing is shown
    kiuwanDetailsProvider.refresh();
}
function browseToFile(details, fileName, line) {
    if (!vscode.workspace.rootPath) {
        vscode.window.showInformationMessage('There is no folder opened, cannot browse to defect file.', 'OK');
        return;
    }
    // Refresh details view with details
    kiuwanDetailsProvider.refresh(details);
    // Try to resolve existing file path from opened folder and defect's file, and browse to it
    findWorkspaceFile(vscode.workspace.rootPath, fileName).then(filePath => {
        if (filePath) {
            vscode.workspace.openTextDocument(filePath).then(document => {
                vscode.window.showTextDocument(document).then(editor => {
                    // Our engine's line is one-based and vscode.Position is zero-based
                    var position = new vscode.Position(line - 1, 0);
                    editor.selection = new vscode.Selection(position, position);
                    editor.revealRange(editor.selection, vscode.TextEditorRevealType.InCenter);
                    vscode.commands.executeCommand('workbench.action.focusActiveEditorGroup');
                }); // end showTextDocument.then
            }); // end openTextDocument.then
        }
        else {
            vscode.window.showInformationMessage('File cannot be found, cannot browse to defect file.', 'OK');
        }
    }).catch(error => {
        vscode.window.showInformationMessage('File cannot be found, cannot browse to defect file.', 'OK');
    });
}
function refreshDetails(details) {
    kiuwanDetailsProvider.refresh(details);
}
function findWorkspaceFile(workspaceAbsolutePath, fileRelativePath) {
    return __awaiter(this, void 0, void 0, function* () {
        // Basic case: VSCode's root folder and KLA's analysis basedir are the same
        let candidate = path.join(workspaceAbsolutePath, fileRelativePath);
        if (fs.existsSync(candidate)) {
            return candidate;
        }
        // Cheap search: VSCode's root folder is subfolder of KLA's analysis basedir, try with root folder ancestors
        let shortenedFolderPath = workspaceAbsolutePath.replace(/\\/g, '/');
        let lastSlashIndex = shortenedFolderPath.lastIndexOf('/');
        while (lastSlashIndex >= 0) {
            shortenedFolderPath = shortenedFolderPath.substring(0, lastSlashIndex);
            candidate = path.join(shortenedFolderPath, fileRelativePath);
            if (fs.existsSync(candidate)) {
                return candidate;
            }
            lastSlashIndex = shortenedFolderPath.lastIndexOf('/');
        }
        // Expensive search: KLA's analysis basedir is subfolder of VSCode's root folder, try with root folder descendants
        let includeGlobPattern = '**/' + fileRelativePath;
        try {
            let files = yield vscode.workspace.findFiles(includeGlobPattern, null, 1);
            if (files.length > 0) {
                return files[0].fsPath;
            }
        }
        catch (reason) {
            log.info("Method find files failed because: " + reason);
        }
        // Not found, return null
        return null;
    });
}
//# sourceMappingURL=extension.js.map